# Openbox autostart file for SkinnyDebbie.

# Run the system-wide support stuff
#~ . $GLOBALAUTOSTART

###########################################################################
### In leiu of GLOBALAUTOSTART, we have copied the contents of
### /etc/xdg/openbox/autostart.sh here and hand tweaked it. This
### is the most reliable way to assure that neither gnome-settings-daemon
### nor xfce-mcs-manager start.
### The following bits are from /etc/xdg/openbox/autostart.sh:
###########################################################################
# This shell script is run before Openbox launches.
# Environment variables set here are passed to the Openbox session.

# Set a background color
BG=""
if which hsetroot >/dev/null; then
	BG=hsetroot
else
	if which esetroot >/dev/null; then
	BG=esetroot
	else
		if which xsetroot >/dev/null; then
			BG=xsetroot
		fi
	fi
fi
test -z $BG || $BG -solid "#303030"

# D-bus
if which dbus-launch >/dev/null && test -z "$DBUS_SESSION_BUS_ADDRESS"; then
	eval `dbus-launch --sh-syntax --exit-with-session`
fi

#~ # Make GTK apps look and behave how they were set up in the gnome config tools
#~ if test -x /usr/libexec/gnome-settings-daemon >/dev/null; then
  #~ /usr/libexec/gnome-settings-daemon &
#~ elif which gnome-settings-daemon >/dev/null; then
  #~ gnome-settings-daemon &
#~ # Make GTK apps look and behave how they were set up in the XFCE config tools
#~ elif which xfce-mcs-manager >/dev/null; then
  #~ xfce-mcs-manager n &
#~ fi

# Preload stuff for KDE apps
#~ if which start_kdeinit >/dev/null; then
  #~ LD_BIND_NOW=true start_kdeinit --new-startup +kcminit_startup &
#~ fi

# Run XDG autostart things.  By default don't run anything desktop-specific
# See xdg-autostart --help more info
DESKTOP_ENV=""
if which /usr/lib/openbox/xdg-autostart >/dev/null; then
  /usr/lib/openbox/xdg-autostart $DESKTOP_ENV
fi
################################################################################
### End of /etc/xdg/openbox/autostart.sh #######################################
################################################################################


###########################################################################
# Programs that will run after Openbox has started
###########################################################################

# SCIM support (for typing non-english characters)
#export LC_CTYPE=ja_JP.utf8
#export XMODIFIERS=@im=SCIM
#export GTK_IM_MODULE=scim
#export QT_IM_MODULE=scim
#scim -d &

# turn off system beep if you want:
# xset b off

# Force OpenOffice.org to use GTK theme; from:
# http://crunchbang.org/archives/2007/12/23/openbox-openoffice-dot-org-and-gtk/
# http://urukrama.wordpress.com/openbox-guide/#OpenOffice
export OOO_FORCE_DESKTOP=gnome
export SAL_USE_VCLPLUGIN=gtk

# initilize paths
#   path to config dir
SKINNY_CFG_DIR=$HOME/.config/skinny-desktop
if [ ! -d $SKINNY_CFG_DIR ] ; then
	mkdir $SKINNY_CFG_DIR
fi

# path to preferred_filemanager link (used by fbpanel menu items)
PREFERRED_FILEMANAGER=$SKINNY_CFG_DIR/preferred_filemanager

# make sure links to needed resources are available
# link skinnybarrc: if there is no skinnybarrc in fbpanel's config dir,
# make a link to the one in $SKINNY_CFG_DIR
if [ ! -e  $HOME/.config/fbpanel/skinnybarrc ] ; then
	ln -sf $SKINNY_CFG_DIR/skinnybarrc $HOME/.config/fbpanel/skinnybarrc
fi

# init trackpad
## gsynaptics is now a transitional package for gpointing-device-settings,
## which is a problem because g-d-s has no gsynaptics-init equivalent.
## So until (unless?) this is fixed, we handjob it in user-startup.
## You can also 

################################################################################
# set desired config #
################################################################################

DESIRED_CONFIG=thunar_1
#~ DESIRED_CONFIG=rox_1

#-------------------------------------------------------------------------------
# thunar_1: thunar, one fbpanel with tray, conky
#-------------------------------------------------------------------------------
if [ $DESIRED_CONFIG = thunar_1 ] ; then
	ln -sf /usr/bin/thunar $PREFERRED_FILEMANAGER
	thunar --daemon &
	fbpanel -p skinnybarrc &
	until ps x | grep fbpanel | grep "\-p skinnybarrc" | grep -v grep >/dev/null
	do 
		sleep 2
	done
	sleep 3 && ( conky -c $SKINNY_CFG_DIR/conkyrc )		# US version
#	sleep 3 && ( conky -c $SKINNY_CFG_DIR/conkyeurc )	# EU version


#-------------------------------------------------------------------------------
# rox_1: rox as desktop manager, gkrellm for sys info, one fbpanel with tray
#-------------------------------------------------------------------------------
elif [ $DESIRED_CONFIG = rox_1 ] ; then
	ln -sf /usr/bin/rox $PREFERRED_FILEMANAGER
	rox --pinboard=myPinboard &
	fbpanel -p skinnybarrc &
	until ps x | grep fbpanel | grep "\-p skinnybarrc" | grep -v grep >/dev/null
	do 
		sleep 2
	done
	sleep 4
	if which gkrellm >/dev/null; then
		gkrellm -w &
	fi

#-------------------------------------------------------------------------------
# default
#-------------------------------------------------------------------------------
else
	ln -sf /usr/bin/thunar $PREFERRED_FILEMANAGER
	thunar --daemon &
	fbpanel -p skinnybarrc &
fi

# Set wallpaper
if which skinny-randyroot >/dev/null; then
#	sleep 2 && ( skinny-randyroot ~/Pictures/Wallpaper & )
	skinny-randyroot ~/Pictures/Wallpaper &
fi

################################################################################
# start misc apps
################################################################################

USER_STARTUP=$SKINNY_CFG_DIR/user-startup
# user-configured startup apps:
if [ ! -e "$SKINNY_CFG_DIR/user-startup" ] ; then
	cat > $USER_STARTUP <<EOT
########################################################################
# Add extra programs/commands you want to launch with SkinnyDebbie here.
# BE SURE TO ADD A '&' AFTER EACH COMMAND!!!
########################################################################
EOT

	if which wicd-client >/dev/null; then
		echo "wicd-client &" >> $USER_STARTUP
	elif which nm-applet >/dev/null; then
		echo "nm-applet --sm-disable &" >> $USER_STARTUP
	fi

	if which skinny-upgrade-notify >/dev/null; then
		echo "(sleep 30 && skinny-upgrade-notify) &" >> $USER_STARTUP
	elif which update-notifier >/dev/null; then
		echo "update-notifier --startup-delay=60 &" >> $USER_STARTUP
	fi

	if which gnome-power-manager >/dev/null; then
		echo "gnome-power-manager &" >> $USER_STARTUP
		if which gnome-screensaver >/dev/null; then
			echo "gnome-screensaver &" >> $USER_STARTUP
		elif which xscreensaver >/dev/null; then
			echo "xscreensaver-command -exit" >> $USER_STARTUP
			echo "xscreensaver -no-splash &" >> $USER_STARTUP
		fi
	else
		if which xfce4-power-manager >/dev/null; then
			echo "xfce4-power-manager &" >> $USER_STARTUP
		fi
		if which xscreensaver >/dev/null; then
			echo "xscreensaver-command -exit" >> $USER_STARTUP
			echo "xscreensaver -no-splash &" >> $USER_STARTUP
		elif which gnome-screensaver >/dev/null; then
			echo "gnome-screensaver &" >> $USER_STARTUP
		fi
	fi

	if which volumeicon >/dev/null; then
		echo "volumeicon &" >> $USER_STARTUP
	elif which gnome-volume-control-applet >/dev/null; then
		echo "gnome-volume-control-applet &" >> $USER_STARTUP
	fi
	echo "" >> $USER_STARTUP
fi
sleep 2 && ( bash $SKINNY_CFG_DIR/user-startup & )

################################################################################
# ADD ADDITIONAL PROGRAMS YOU WANT TO LAUNCH AT STARTUP TO THE FILE
# ~/.config/skinny-desktop/user-startup.
################################################################################
